Calculate chromosome lengths for a map object
chr_lengths(map, collapse_to_AX = FALSE)A vector of chromosome lengths. If
collapse_to_AX=TRUE, the result is a vector of length 2
(autosomal and X chromosome lengths).
A list of vectors, each specifying locations of the markers. Can also be a cross2 object, in which case the genetic map (if present) is used.
If TRUE, collapse to the total lengths of the autosomes and X chromosome.
We take diff(range(v)) for each vector, v.
scan1perm()