| plot_ci | R Documentation |
Plot a set of confidence intervals.
plot_ci(
est,
se = NULL,
lo = NULL,
hi = NULL,
SEmult = 2,
labels = NULL,
rotate = FALSE,
...
)
est |
Vector of estimates |
se |
Vector of standard errors |
lo |
Vector of lower values for the intervals |
hi |
Vector of upper values for the intervals |
SEmult |
SE multiplier to create intervals |
labels |
Labels for the groups (vector of character strings) |
rotate |
If TRUE, have group as y-axis; default (FALSE) has group on x-axis. |
... |
Optional graphics arguments |
Provide either se or both lo and hi. In the case that se is
used, the intervals will be est +/- SEmult * se.
If labels is not provided, group names are taken from the names(est).
If that is also missing, we use capital letters.
You can control the CI line widths with ci_lwd and the color of
the CI segments with ci_col. You can control the width of the
segments at the top and bottom with ci_endseg.
None.
plot_coef(), plot_pxg(), fit1(), pull_genoprobpos()
iron <- read_cross2(system.file("extdata", "iron.zip", package="qtl2"))
iron <- iron[,"9"] # only chr 9
map <- insert_pseudomarkers(iron$gmap, step=1)
probs <- calc_genoprob(iron, map, error_prob=0.002)
pr <- pull_genoprobpos(probs, map, chr="9", pos=56.6)
out_fit1 <- fit1(pr, iron$pheno[,"spleen"], se=TRUE, zerosum=FALSE)
plot_ci(out_fit1$coef[1:3], out_fit1$SE[1:3],
xlab="Genotype chr 9 @ 56.6 cM", ylab="Spleen phenotype")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.