- genoprobs
Genotype probabilities as calculated by
calc_genoprob().
- pheno
A numeric vector of phenotype values (just one phenotype, not a matrix of them)
- kinship
Optional kinship matrix, or a list of kinship matrices (one
per chromosome), in order to use the LOCO (leave one chromosome
out) method.
- addcovar
An optional numeric matrix of additive covariates.
- nullcovar
An optional numeric matrix of additional additive
covariates that are used under the null hypothesis (of no QTL) but
not under the alternative (with a QTL). This is needed for the X
chromosome, where we might need sex as a additive covariate under
the null hypothesis, but we wouldn't want to include it under the
alternative as it would be collinear with the QTL effects. Only
used if kinship is provided but hsq is not, to get
estimate of residual heritability.
- intcovar
An optional numeric matrix of interactive covariates.
- weights
An optional numeric vector of positive weights for the
individuals. As with the other inputs, it must have names
for individual identifiers.
- contrasts
An optional numeric matrix of genotype contrasts, size
genotypes x genotypes. For an intercross, you might use
cbind(mu=c(1,1,1), a=c(-1, 0, 1), d=c(0, 1, 0)) to get
mean, additive effect, and dominance effect. The default is the
identity matrix.
- model
Indicates whether to use a normal model (least
squares) or binary model (logistic regression) for the phenotype.
If model="binary", the phenotypes must have values in \([0, 1]\).
- zerosum
If TRUE, force the genotype or allele coefficients
sum to 0 by subtracting their mean and add another column with
the mean. Ignored if contrasts is provided.
Note: the standard errors aren't quite right when zerosum=TRUE;
use fit1() to get proper standard errors.
- se
If TRUE, also calculate the standard errors.
- hsq
(Optional) residual heritability; used only if
kinship provided.
- reml
If kinship provided: if reml=TRUE, use
REML; otherwise maximum likelihood.
- ...
Additional control parameters; see Details;