Learn R Programming

qtl2 (version 0.42)

cbind.phasedgeno: Join phased genotype results for different chromosomes

Description

Join multiple phased genotype objects, as produced by guess_phase(), for the same set of individuals but different chromosomes.

Usage

# S3 method for phasedgeno
cbind(...)

Value

An object of class "phasedgeno", like the input; see guess_phase().

Arguments

...

Imputed genotype objects as produced by guess_phase(). Must have the same set of individuals.

See Also

rbind.phasedgeno(), subset.phasedgeno(), guess_phase()

Examples

Run this code
if (FALSE) {
file <- paste0("https://raw.githubusercontent.com/rqtl/",
               "qtl2data/main/DOex/DOex.zip")
DOex <- read_cross2(file)
pr <- calc_genoprob(DOex, error_prob=0.002)
m <- maxmarg(pr)
phA <- guess_phase(DOex[,2], m[,2])
phB <- guess_phase(DOex[,3], m[,3])
ph <- cbind(phA, phB)
}

Run the code above in your browser using DataLab