- peaks
Data frame of QTL results, as output by find_peaks()
Should contain columns lodcolumn, chr, and pos.
- map
Marker map, as a list of chromosomes, each being a
vector of positions; used to get chromosome names and start/end
- pheno_pos
Data frame with chromosome, position, and name of
the phenotypes in peaks. Should contain columns pheno,
chr, and pos.
- gap
Gap between chromosomes in the plot
- cis_window
Window size that defines cis-QTL (on same
chromosome, and position of gene within this distance of QTL
position)
- pch
Point type for "trans" points
- col
Point color for "trans" points
- bg
Background color for "trans" points
- cex
Character expansion size for "trans" points
- pch_cis
Point type for "cis" points
- col_cis
Point color for "cis" points
- bg_cis
Background color for "cis" points
- cex_cis
Character expansion size for "cis" points
- pty
Plot type; the default "s" forces a square plot; use "m"
to use the maximal plotting region.
- bgcolor
Background color for chromosome rectangles
- altbgcolor
Alternate background color for chromosome rectangles
- ...
Additional graphics arguments passed to graphics::points()